import 'package:dyte_core/dyte_core.dart';
import 'package:dyte_core_example/models/states/participant_event_states.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class ParticipantNotifier extends StateNotifier<ParticipantEventStates>
    with DyteParticipantEventsListener {
  ParticipantNotifier() : super(const ParticipantEventStates.initial());

  @override
  void onAudioUpdate(
    bool audioEnabled,
    DyteMeetingParticipant participant,
  ) {
    state = ParticipantEventStates.onAudioUpdate(
        audioEnabled: audioEnabled, participant: participant);
  }

  @override
  void onActiveSpeakerChanged(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onActiveSpeakerChanged(participant);
  }

  @override
  void onNoActiveSpeaker() {
    state = const ParticipantEventStates.onNoActiveSpeaker();
  }

  @override
  void onParticipantJoin(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onParticipantJoin(participant);
  }

  @override
  void onParticipantLeave(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onParticipantLeave(participant);
  }

  @override
  void onParticipantPinned(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onParticipantPinned(participant);
  }

  @override
  void onActiveParticipantsChanged(List<DyteMeetingParticipant> active) {
    state = ParticipantEventStates.onActiveParticipantsChanged(
        activeParticipants: active);
  }

  @override
  void onParticipantUnpinned() {
    state = const ParticipantEventStates.onParticipantUnpinned();
  }

  @override
  void onScreenSharesUpdated() {
    state = const ParticipantEventStates.onScreenSharesUpdated();
  }

  @override
  void onVideoUpdate(
    bool videoEnabled,
    DyteMeetingParticipant participant,
  ) {
    state = ParticipantEventStates.onVideoUpdate(
        videoEnabled: videoEnabled, participant: participant);
  }

  @override
  void onUpdate(DyteRoomParticipants participants) {
    state = ParticipantEventStates.onUpdate(participants);
  }

  @override
  void onWaitListParticipantAccepted(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onWaitListParticipantAccepted(participant);
  }

  @override
  void onWaitListParticipantJoined(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onWaitListParticipantJoined(participant);
  }

  @override
  void onWaitListParticipantRejected(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onWaitListParticipantRejected(participant);
  }

  @override
  void onWaitListParticipantClosed(DyteMeetingParticipant participant) {
    state = ParticipantEventStates.onWaitListParticipantClosed(participant);
  }
}
