import 'dart:developer';

import 'package:dyte_core/dyte_core.dart';
import 'package:dyte_core_example/constants/colors.dart';
import 'package:dyte_core_example/models/meeting_details.dart';
import 'package:dyte_core_example/models/participant_details.dart';
import 'package:dyte_core_example/models/states/room_event_states.dart';
import 'package:dyte_core_example/providers/providers.dart';
import 'package:dyte_core_example/repository/meeting_handler.dart';
import 'package:dyte_core_example/secrets.dart';
import 'package:dyte_core_example/ui/meeting/room/staging_room.dart';
import 'package:dyte_core_example/ui/widgets/appbar.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class HomePage extends ConsumerStatefulWidget {
  const HomePage({super.key});

  @override
  ConsumerState<HomePage> createState() => _HomePageState();
}

class _HomePageState extends ConsumerState<HomePage> {
  final nameController = TextEditingController();

  final descriptionController = TextEditingController();

  final roomNameController = TextEditingController();

  final meetingRepo = MeetingRepository();

  MeetingDetails? meetingDetails;
  ParticipantTokens? participantTokens;

  @override
  Widget build(BuildContext context) {
    ref.listen<RoomEventStates>(roomEventStateNotifierProvider, (_, next) {
      next.maybeWhen(
        onMeetingInitFailed: (exception) {
          log('onMeetingInitFailed', name: 'core');
        },
        onMeetingInitStarted: () {
          log('onMeetingInitStarted', name: 'core');
        },
        onMeetingInitCompleted: () async {
          log('onMeetingInitCompleted', name: 'core');

          if (mounted) {
            Navigator.push(context, MaterialPageRoute(builder: (context) {
              return const StagingRoom();
            }));
          }
        },
        orElse: () {},
      );
    });
    return Scaffold(
      appBar: const DyteAppBar(),
      body: Center(child: _meetingDetails(meetingRoomName)),
    );
  }

  Widget _meetingDetails(String meetLink) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        GestureDetector(
          onTap: () {
            Clipboard.setData(
                ClipboardData(text: 'https://app.dyte.io/$meetLink'));
          },
          child: Text('https://app.dyte.io/$meetLink'),
        ),
        const SizedBox(height: 10),
        MaterialButton(
          onPressed: () {
            ref.watch(dyteClient).addMeetingRoomEventsListener(
                ref.watch(roomEventStateNotifierProvider.notifier));
            ref.watch(dyteClient).addParticipantEventsListener(
                ref.watch(participantEventStateNotifierProvider.notifier));
            ref
                .watch(dyteClient)
                .addSelfEventsListener(ref.watch(localUserProvider.notifier));
            ref.watch(dyteClient).addPluginEventsListener(
                  ref.watch(pluginEventStateNotifierProvider.notifier),
                );
            ref.watch(dyteClient).addChatEventsListener(
                  ref.watch(dyteChatProvider.notifier),
                );
            ref.watch(dyteClient).init(
                  DyteMeetingInfo(
                    roomName: meetingRoomName,
                    // enableAudio: false,
                    displayName: 'Flutter core',
                    authToken: authToken,
                  ),
                );
          },
          minWidth: 180,
          height: 45,
          color: DyteColors.primary,
          child: const Text(
            "Join Meeting",
            style: TextStyle(fontSize: 16),
          ),
        )
      ],
    );
  }
}
