import 'package:dyte_core/dyte_core.dart';
import 'package:dyte_core_example/constants/colors.dart';
import 'package:dyte_core_example/models/states/participant_event_states.dart';
import 'package:dyte_core_example/providers/providers.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class JoinedParticipants extends ConsumerStatefulWidget {
  final List<DyteMeetingParticipant> joinedParticipants;
  const JoinedParticipants({
    super.key,
    required this.joinedParticipants,
  });

  @override
  ConsumerState<JoinedParticipants> createState() => _JoinedParticipantsState();
}

class _JoinedParticipantsState extends ConsumerState<JoinedParticipants> {
  _renderStateIcon(Icon icon) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Container(
          height: 42,
          width: 42,
          decoration: BoxDecoration(
              color: Colors.grey.shade800,
              borderRadius: const BorderRadius.all(Radius.circular(4))),
          child: icon),
    );
  }

  Widget _renderParticipantInfo(DyteMeetingParticipant participant) {
    // final hostPermissions = ref.watch(dyteClient).permissions.hostPermissions;
    return Row(
      key: Key(
          '${participant.id}${participant.audioEnabled}${participant.videoEnabled}'),
      children: [
        Text(
          participant.name,
          style: const TextStyle(fontSize: 18),
        ),
        const Spacer(),
        // if (hostPermissions.canPinParticipant)
        //   IconButton(
        //     onPressed: () {
        //       (ref.watch(dyteClient).participants.pinned != null &&
        //               ref.watch(dyteClient).participants.pinned!.id ==
        //                   participant.id)
        //           ? ref.watch(dyteClient).hostActions.unpinParticipant()
        //           : ref
        //               .watch(dyteClient)
        //               .hostActions
        //               .pinParticipant(participant);
        //     },
        //     icon: Icon(
        //       (ref.watch(dyteClient).participants.pinned != null &&
        //               ref.watch(dyteClient).participants.pinned!.id ==
        //                   participant.id)
        //           ? Icons.push_pin
        //           : Icons.push_pin_outlined,
        //       color: Colors.white,
        //     ),
        //   ),
        participant.audioEnabled
            ? _renderStateIcon(const Icon(Icons.mic_none_outlined))
            : _renderStateIcon(Icon(
                Icons.mic_off_outlined,
                color: DyteColors.red,
              )),
        participant.videoEnabled
            ? _renderStateIcon(const Icon(Icons.videocam))
            : _renderStateIcon(
                Icon(Icons.videocam_off_outlined, color: DyteColors.red))
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    ref.listen<ParticipantEventStates>(participantEventStateNotifierProvider,
        (previous, next) {
      next.maybeMap(
        orElse: () {},
        onParticipantPinned: (_) {
          setState(() {});
        },
        onParticipantUnpinned: (_) {
          setState(() {});
        },
      );
    });
    final participants = widget.joinedParticipants;
    return SizedBox(
      height: MediaQuery.of(context).size.height * .9,
      child: ListView.separated(
        separatorBuilder: (context, index) => const Divider(),
        padding: const EdgeInsets.symmetric(horizontal: 8),
        itemCount: participants.length,
        itemBuilder: (context, index) =>
            _renderParticipantInfo(participants[index]),
      ),
    );
  }
}
