import 'package:dyte_core/dyte_core.dart';
import 'package:dyte_core_example/providers/providers.dart';
import 'package:dyte_core_example/ui/meeting/joined_participants.dart';
import 'package:dyte_core_example/ui/meeting/waitlisted_participants.dart';
import 'package:dyte_core_example/ui/widgets/appbar.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class ParticipantScreen extends ConsumerWidget {
  const ParticipantScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final size = MediaQuery.of(context).size;
    return Scaffold(
      appBar: const DyteAppBar(),
      body: SizedBox(
        height: size.height,
        child: StreamBuilder<DyteRoomParticipants>(
          stream: ref.watch(dyteClient).participantsStream,
          initialData: ref.watch(dyteClient).participants,
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              return SingleChildScrollView(
                child: Column(
                  children: [
                    if (snapshot.data!.waitlisted.isNotEmpty) ...[
                      const Text(
                        "Waitlisted",
                        textAlign: TextAlign.center,
                      ),
                      WaitlistedParticipants(
                          waitlistedParticipants: snapshot.data!.waitlisted)
                    ],
                    const Text(
                      "In Call",
                      textAlign: TextAlign.center,
                    ),
                    JoinedParticipants(
                        joinedParticipants: snapshot.data!.joined)
                  ],
                ),
              );
            }
            return const SizedBox.shrink();
          },
        ),
      ),
    );
  }
}
