import 'package:dyte_core/dyte_core.dart';
import 'package:dyte_core_example/models/states/participant_event_states.dart';
import 'package:dyte_core_example/providers/providers.dart';
import 'package:dyte_core_example/router/app_router.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class ScreenShareView extends ConsumerStatefulWidget {
  final DyteMeetingParticipant screensharePeer;
  const ScreenShareView({
    super.key,
    required this.screensharePeer,
  });

  @override
  ConsumerState<ScreenShareView> createState() => _ScreenShareViewState();
}

class _ScreenShareViewState extends ConsumerState<ScreenShareView> {
  @override
  Widget build(BuildContext context) {
    ref.listen<ParticipantEventStates>(participantEventStateNotifierProvider,
        (previous, next) {
      next.maybeMap(
        orElse: () {},
        onUpdate: (res) {
          if (!res.participants.screenshares.contains(widget.screensharePeer)) {
            AppRouter.of(context).pop();
            ScaffoldMessenger.of(context).showSnackBar(
              SnackBar(
                content:
                    Text("${widget.screensharePeer.name} stopped screenshare!"),
              ),
            );
          }
        },
      );
    });

    const viewType = 'DytePlatformScreenshareView';
    final Map<String, dynamic> creationParams = {
      'peerId': widget.screensharePeer.id,
    };

    final size = MediaQuery.of(context).size;

    return AspectRatio(
      aspectRatio: 16 / 9,
      child: SizedBox(
        height: size.height,
        width: size.width,
        child: LayoutBuilder(
          builder: (ctx, constraints) {
            switch (defaultTargetPlatform) {
              case TargetPlatform.android:
                return PlatformViewLink(
                  key: Key(widget.screensharePeer.id),
                  surfaceFactory: (context, controller) {
                    return AndroidViewSurface(
                      controller: controller as AndroidViewController,
                      hitTestBehavior: PlatformViewHitTestBehavior.opaque,
                      gestureRecognizers: <
                          Factory<OneSequenceGestureRecognizer>>{
                        Factory<EagerGestureRecognizer>(
                            () => EagerGestureRecognizer()),
                        Factory<TapGestureRecognizer>(
                            () => TapGestureRecognizer()),
                      },
                    );
                  },
                  onCreatePlatformView: (params) {
                    return PlatformViewsService.initAndroidView(
                      id: params.id,
                      viewType: viewType,
                      creationParams: creationParams,
                      creationParamsCodec: const StandardMessageCodec(),
                      onFocus: () => params.onFocusChanged(true),
                      layoutDirection: TextDirection.ltr,
                    )
                      ..addOnPlatformViewCreatedListener(
                          params.onPlatformViewCreated)
                      ..create();
                  },
                  viewType: viewType,
                );

              case TargetPlatform.iOS:
                return ClipRRect(
                  child: UiKitView(
                    key: Key(widget.screensharePeer.id),
                    viewType: viewType,
                    layoutDirection: TextDirection.ltr,
                    creationParams: creationParams,
                    creationParamsCodec: const StandardMessageCodec(),
                  ),
                );
              default:
                throw UnsupportedError('Unsupported platform view');
            }
          },
        ),
      ),
    );
  }
}
