import 'package:dyte_core/dyte_core.dart';
import 'package:dyte_core_example/models/states/participant_event_states.dart';
import 'package:dyte_core_example/providers/providers.dart';
import 'package:dyte_core_example/ui/meeting/screenshares/screen_share_view.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

import '../../../router/app_router.dart';

class ScreensharesListPage extends ConsumerStatefulWidget {
  const ScreensharesListPage({super.key});

  @override
  ConsumerState<ScreensharesListPage> createState() =>
      _ScreensharesListPageState();
}

class _ScreensharesListPageState extends ConsumerState<ScreensharesListPage> {
  late List<DyteMeetingParticipant> screensharePeers;

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    screensharePeers = ref.watch(dyteClient).participants.screenshares;
  }

  @override
  Widget build(BuildContext context) {
    ref.listen<ParticipantEventStates>(
      participantEventStateNotifierProvider,
      (previous, next) {
        next.maybeMap(
          orElse: () {},
          onUpdate: (res) {
            final updatedScreensharePeers = res.participants.screenshares;
            if (screensharePeers != updatedScreensharePeers) {
              screensharePeers = updatedScreensharePeers;
              setState(() {});
            }
          },
          onScreenSharesUpdated: (res) {},
        );
      },
    );

    final size = MediaQuery.of(context).size;
    return Scaffold(
      appBar: AppBar(
        title: const Text("ScreenShares"),
        centerTitle: true,
      ),
      body: SizedBox(
        height: size.height * .7,
        width: size.width,
        child: ListView.builder(
          itemBuilder: (context, index) {
            final peer = screensharePeers[index];
            return ListTile(
              tileColor: Colors.black,
              title: Text(
                peer.name,
                style: const TextStyle(color: Colors.white),
              ),
              trailing: IconButton(
                  onPressed: () {
                    AppRouter.of(context)
                        .push(ScreenShareView(screensharePeer: peer));
                  },
                  icon: const Icon(Icons.tv)),
            );
          },
          itemCount: screensharePeers.length,
        ),
      ),
    );
  }
}
